@@ -23,7 +23,7 @@ use crate::prelude::*;
 /// Contains M68K-specific details for an instruction
 pub struct M68kInsnDetail<'a>(pub(crate) &'a cs_m68k);
 
-impl<'a> M68kInsnDetail<'a> {
+impl M68kInsnDetail<'_> {
     /// size of data operand works on in bytes (.b, .w, .l, etc)
     pub fn op_size(&self) -> Option<M68kOpSize> {
         M68kOpSize::new(&self.0.op_size)
@@ -444,7 +444,7 @@ impl_PartialEq_repr_fields!(M68kOpMem;
 
 impl cmp::Eq for M68kOpMem {}
 
-impl<'a> From<&'a cs_m68k_op> for M68kOperand {
+impl From<&cs_m68k_op> for M68kOperand {
     fn from(insn: &cs_m68k_op) -> M68kOperand {
         M68kOperand::new(insn)
     }
@@ -463,11 +463,9 @@ def_arch_details_struct!(
 #[cfg(test)]
 mod test {
     use super::*;
-    use alloc::vec::Vec;
     use capstone_sys::m68k_address_mode::*;
     use capstone_sys::m68k_op_type::*;
     use capstone_sys::m68k_reg::*;
-    use crate::instruction::*;
 
     const MEM_ZERO: m68k_op_mem = m68k_op_mem {
         base_reg: M68K_REG_INVALID,
@@ -555,7 +553,7 @@ mod test {
     fn register_bits_mask() {
         assert_eq!(
             M68K_REGISTER_BITS_ALLOWED_MASK,
-            0b11111111_11111111_11111111
+            0b1111_1111_1111_1111_1111_1111
         );
     }
 
@@ -571,16 +569,16 @@ mod test {
     fn register_bits_from_iter() {
         let empty: &[m68k_reg::Type] = &[];
         assert_eq!(
-            M68kRegisterBits::from_register_iter(empty.into_iter().map(|x| *x)),
+            M68kRegisterBits::from_register_iter(empty.iter().copied()),
             Ok(M68kRegisterBits { bits: 0 })
         );
         assert_eq!(
-            M68kRegisterBits::from_register_iter([M68K_REG_D1].iter().map(|x| *x)),
+            M68kRegisterBits::from_register_iter([M68K_REG_D1].iter().copied()),
             Ok(M68kRegisterBits { bits: 0b10 })
         );
         assert_eq!(
             M68kRegisterBits::from_register_iter(
-                [M68K_REG_D1, M68K_REG_A2, M68K_REG_FP7].iter().map(|x| *x)
+                [M68K_REG_D1, M68K_REG_A2, M68K_REG_FP7].iter().copied()
             ),
             Ok(M68kRegisterBits {
                 bits: 0b1000_0000_0000_0100_0000_0010
@@ -608,14 +606,13 @@ mod test {
             M68kOperand::RegBits(
                 M68kRegisterBits::from_register_iter(
                     [M68K_REG_D0, M68K_REG_D2, M68K_REG_A2, M68K_REG_A3]
-                        .iter()
-                        .map(|x| *x)
+                        .iter().copied()
                 )
                 .unwrap()
             ),
             M68kOperand::RegBits(
                 M68kRegisterBits::from_register_iter(
-                    [M68K_REG_D0, M68K_REG_A2, M68K_REG_A3].iter().map(|x| *x)
+                    [M68K_REG_D0, M68K_REG_A2, M68K_REG_A3].iter().copied()
                 )
                 .unwrap()
             )
@@ -634,8 +631,11 @@ mod test {
         );
     }
 
+    #[cfg(feature = "full")]
     #[test]
     fn extra_info() {
+        use alloc::vec::Vec;
+        use crate::instruction::*;
         use crate::arch::DetailsArchInsn;
 
         let cs = Capstone::new()
@@ -651,16 +651,14 @@ mod test {
         ];
         let code: Vec<u8> = code_parts
             .iter()
-            .map(|x| x.iter())
-            .flatten()
-            .map(|x| *x)
+            .flat_map(|x| x.iter()).copied()
             .collect();
         let insns = cs.disasm_all(&code, 0x1000).expect("Failed to disasm");
         let mut insns_iter = insns.iter();
 
         // jsr
         let insn_jsr: &Insn = insns_iter.next().unwrap();
-        let detail = cs.insn_detail(&insn_jsr).unwrap();
+        let detail = cs.insn_detail(insn_jsr).unwrap();
         let _arch_detail = detail.arch_detail();
         let arch_detail = _arch_detail.m68k().unwrap();
         let mut ops = arch_detail.operands();
