@@ -42,13 +42,14 @@ impl X86OperandType {
 }
 
 /// X86 operand
-#[derive(Clone, Debug, PartialEq)]
+#[derive(Clone, Debug, PartialEq, Eq)]
 pub struct X86Operand {
     /// Operand size
     pub size: u8,
 
-    /// How is this operand accessed? NOTE: this field is irrelevant if engine
-    /// is compiled in DIET mode.
+    /// How is this operand accessed?
+    ///
+    /// NOTE: this field is always `None` if the "full" feataure is not enabled.
     pub access: Option<RegAccessType>,
 
     /// AVX broadcast
@@ -62,7 +63,7 @@ pub struct X86Operand {
 }
 
 /// X86 operand
-#[derive(Clone, Debug, PartialEq)]
+#[derive(Clone, Debug, PartialEq, Eq)]
 pub enum X86OperandType {
     /// Register
     Reg(RegId),
@@ -81,19 +82,19 @@ pub enum X86OperandType {
 #[derive(Debug, Copy, Clone)]
 pub struct X86OpMem(pub(crate) x86_op_mem);
 
-impl<'a> X86InsnDetail<'a> {
+impl X86InsnDetail<'_> {
     /// Instruction prefix, which can be up to 4 bytes.
     /// A prefix byte gets value 0 when irrelevant.
     /// See `X86Prefix` for details.
     ///
-    /// prefix[0] indicates REP/REPNE/LOCK prefix (See `X86_PREFIX_REP`/`REPNE`/`LOCK`)
+    /// `prefix[0]` indicates REP/REPNE/LOCK prefix (See `X86_PREFIX_REP`/`REPNE`/`LOCK`)
     ///
-    /// prefix[1] indicates segment override (irrelevant for x86_64):
+    /// `prefix[1]` indicates segment override (irrelevant for x86_64):
     /// See `X86_PREFIX_CS`/`SS`/`DS`/`ES`/`FS`/`GS`.
     ///
-    /// prefix[2] indicates operand-size override (`X86_PREFIX_OPSIZE`)
+    /// `prefix[2]` indicates operand-size override (`X86_PREFIX_OPSIZE`)
     ///
-    /// prefix[3] indicates address-size override (`X86_PREFIX_ADDRSIZE`)
+    /// `prefix[3]` indicates address-size override (`X86_PREFIX_ADDRSIZE`)
     pub fn prefix(&self) -> &[u8; 4] {
         &self.0.prefix
     }
@@ -221,7 +222,7 @@ impl Default for X86Operand {
     }
 }
 
-impl<'a> From<&'a cs_x86_op> for X86Operand {
+impl From<&cs_x86_op> for X86Operand {
     fn from(op: &cs_x86_op) -> X86Operand {
         let op_type = X86OperandType::new(op.type_, op.__bindgen_anon_1);
         X86Operand {
@@ -285,7 +286,7 @@ mod test {
         };
 
         assert_eq!(a1, a1.clone());
-        assert_ne!(a1, a2.clone());
+        assert_ne!(a1, a2);
     }
 
     #[test]
@@ -335,7 +336,7 @@ mod test {
             ; 8],
 
         };
-        let mut a2 = a1.clone();
+        let mut a2 = a1;
         a2.operands[1].type_ = x86_op_type::X86_OP_REG;
         let a1_clone = cs_x86 {
             ..a1
@@ -348,7 +349,7 @@ mod test {
             op_count: 1,
             ..a1
         };
-        let mut op1_differ = op_count_differ.clone();
+        let mut op1_differ = op_count_differ;
         op1_differ.operands[0].avx_bcast = x86_avx_bcast::X86_AVX_BCAST_2;
 
         t_eq(&a1, &a1);
