@@ -1,8 +1,8 @@
-use alloc::string::{String, ToString};
+use alloc::string::String;
 use core::convert::From;
 use core::marker::PhantomData;
 
-use libc::{c_int, c_uint, c_void};
+use libc::{c_int, c_void};
 
 use capstone_sys::cs_opt_value::*;
 use capstone_sys::*;
@@ -10,9 +10,10 @@ use capstone_sys::*;
 use crate::arch::CapstoneBuilder;
 use crate::constants::{Arch, Endian, ExtraMode, Mode, OptValue, Syntax};
 use crate::error::*;
-use crate::ffi::str_from_cstr_ptr;
 use crate::instruction::{Insn, InsnDetail, InsnGroupId, InsnId, Instructions, RegId};
 
+use {crate::ffi::str_from_cstr_ptr, alloc::string::ToString, libc::c_uint};
+
 /// An instance of the capstone disassembler
 ///
 /// Create with an instance with [`.new()`](Self::new) and disassemble bytes with [`.disasm_all()`](Self::disasm_all).
@@ -201,16 +202,8 @@ impl Capstone {
         // it *should* be safe to accept `&self` (instead of `&mut self`) in this method.
 
         let mut ptr: *mut cs_insn = core::ptr::null_mut();
-        let insn_count = unsafe {
-            cs_disasm(
-                self.csh(),
-                code.as_ptr(),
-                code.len() as usize,
-                addr,
-                count as usize,
-                &mut ptr,
-            )
-        };
+        let insn_count =
+            unsafe { cs_disasm(self.csh(), code.as_ptr(), code.len(), addr, count, &mut ptr) };
         if insn_count == 0 {
             match self.error_result() {
                 Ok(_) => Ok(Instructions::new_empty()),
@@ -343,35 +336,48 @@ impl Capstone {
     }
 
     /// Converts a register id `reg_id` to a `String` containing the register name.
+    /// Unavailable in Diet mode
     pub fn reg_name(&self, reg_id: RegId) -> Option<String> {
-        let reg_name = unsafe {
-            let _reg_name = cs_reg_name(self.csh(), c_uint::from(reg_id.0));
-            str_from_cstr_ptr(_reg_name)?.to_string()
-        };
-
-        Some(reg_name)
+        if cfg!(feature = "full") {
+            let reg_name = unsafe {
+                let _reg_name = cs_reg_name(self.csh(), c_uint::from(reg_id.0));
+                str_from_cstr_ptr(_reg_name)?.to_string()
+            };
+            Some(reg_name)
+        } else {
+            None
+        }
     }
 
     /// Converts an instruction id `insn_id` to a `String` containing the instruction name.
-    ///
+    /// Unavailable in Diet mode.
     /// Note: This function ignores the current syntax and uses the default syntax.
     pub fn insn_name(&self, insn_id: InsnId) -> Option<String> {
-        let insn_name = unsafe {
-            let _insn_name = cs_insn_name(self.csh(), insn_id.0 as c_uint);
-            str_from_cstr_ptr(_insn_name)?.to_string()
-        };
+        if cfg!(feature = "full") {
+            let insn_name = unsafe {
+                let _insn_name = cs_insn_name(self.csh(), insn_id.0 as c_uint);
+                str_from_cstr_ptr(_insn_name)?.to_string()
+            };
 
-        Some(insn_name)
+            Some(insn_name)
+        } else {
+            None
+        }
     }
 
     /// Converts a group id `group_id` to a `String` containing the group name.
+    /// Unavailable in Diet mode
     pub fn group_name(&self, group_id: InsnGroupId) -> Option<String> {
-        let group_name = unsafe {
-            let _group_name = cs_group_name(self.csh(), c_uint::from(group_id.0));
-            str_from_cstr_ptr(_group_name)?.to_string()
-        };
+        if cfg!(feature = "full") {
+            let group_name = unsafe {
+                let _group_name = cs_group_name(self.csh(), c_uint::from(group_id.0));
+                str_from_cstr_ptr(_group_name)?.to_string()
+            };
 
-        Some(group_name)
+            Some(group_name)
+        } else {
+            None
+        }
     }
 
     /// Returns `Detail` structure for a given instruction
@@ -380,14 +386,11 @@ impl Capstone {
     ///
     /// 1. Instruction was created with detail enabled
     /// 2. Skipdata is disabled
-    /// 3. Capstone was not compiled in diet mode
     pub fn insn_detail<'s, 'i: 's>(&'s self, insn: &'i Insn) -> CsResult<InsnDetail<'i>> {
         if !self.detail_enabled {
             Err(Error::DetailOff)
         } else if insn.id().0 == 0 {
             Err(Error::IrrelevantDataInSkipData)
-        } else if Self::is_diet() {
-            Err(Error::IrrelevantDataInDiet)
         } else {
             Ok(unsafe { insn.detail(self.arch) })
         }
@@ -409,7 +412,7 @@ impl Capstone {
 
     /// Returns whether the capstone library supports a given architecture.
     pub fn supports_arch(arch: Arch) -> bool {
-        unsafe { cs_support(arch as c_int) }
+        unsafe { cs_support(cs_arch::from(arch) as c_int) }
     }
 
     /// Returns whether the capstone library was compiled in diet mode.
