@@ -72,6 +72,10 @@ capstone_error_def!(
     => UnsupportedX86Masm = CS_ERR_X86_MASM;
 );
 
+// Required until https://github.com/rust-lang/rust/issues/103765 is resolved
+#[cfg(feature = "std")]
+impl std::error::Error for Error {}
+
 pub type CsResult<T> = result::Result<T, Error>;
 
 impl fmt::Display for Error {
