@@ -3,6 +3,8 @@
 use core::{slice, str};
 use libc::{self, c_char};
 
+// This function will go unused in Diet mode
+#[allow(unused)]
 /// Given a valid C-style, NUL terminated, UTF8-encoded string, returns a Rust `&str`
 ///
 /// Warnings:
@@ -10,6 +12,7 @@ use libc::{self, c_char};
 /// - This function "creates" a reference with an arbitrary lifetime, so be careful to limit the
 ///   lifetime appropriately
 #[inline]
+#[allow(clippy::unnecessary_cast)]
 pub(crate) unsafe fn str_from_cstr_ptr<'a>(ptr: *const c_char) -> Option<&'a str> {
     if ptr.is_null() {
         return None;
@@ -24,7 +27,6 @@ pub(crate) unsafe fn str_from_cstr_ptr<'a>(ptr: *const c_char) -> Option<&'a str
 #[cfg(test)]
 mod test {
     use super::*;
-    use core;
 
     #[test]
     fn cstr_convert() {
