@@ -1,5 +1,5 @@
 use alloc::{self, boxed::Box};
-use core::convert::{TryFrom, TryInto};
+use core::convert::TryFrom;
 use core::fmt::{self, Debug, Display, Error, Formatter};
 use core::marker::PhantomData;
 use core::ops::Deref;
@@ -10,6 +10,7 @@ use capstone_sys::*;
 
 use crate::arch::ArchDetail;
 use crate::constants::Arch;
+
 use crate::ffi::str_from_cstr_ptr;
 
 /// Represents a slice of [`Insn`] returned by [`Capstone`](crate::Capstone) `disasm*()` methods.
@@ -63,12 +64,6 @@ impl RegId {
     pub const INVALID_REG: Self = Self(0);
 }
 
-impl core::convert::From<u32> for RegId {
-    fn from(v: u32) -> RegId {
-        RegId(v.try_into().ok().unwrap_or(Self::INVALID_REG.0))
-    }
-}
-
 /// Represents how the register is accessed.
 #[derive(Copy, Clone, Debug, Hash, PartialEq, Eq)]
 pub enum RegAccessType {
@@ -105,13 +100,13 @@ impl TryFrom<cs_ac_type> for RegAccessType {
 
     fn try_from(access: cs_ac_type) -> Result<Self, Self::Error> {
         // Check for flags other than CS_AC_READ or CS_AC_WRITE.
-        let unknown_flag_mask = !(CS_AC_READ | CS_AC_WRITE).0;
+        let unknown_flag_mask = !(cs_ac_type::CS_AC_READ | cs_ac_type::CS_AC_WRITE).0;
         if (access.0 & unknown_flag_mask) != 0 {
             return Err(());
         }
 
-        let is_readable = (access & CS_AC_READ).0 != 0;
-        let is_writable = (access & CS_AC_WRITE).0 != 0;
+        let is_readable = (access & cs_ac_type::CS_AC_READ).0 != 0;
+        let is_writable = (access & cs_ac_type::CS_AC_WRITE).0 != 0;
         match (is_readable, is_writable) {
             (true, false) => Ok(RegAccessType::ReadOnly),
             (false, true) => Ok(RegAccessType::WriteOnly),
@@ -148,7 +143,7 @@ impl<'a> AsRef<[Insn<'a>]> for Instructions<'a> {
     }
 }
 
-impl<'a> Drop for Instructions<'a> {
+impl Drop for Instructions<'_> {
     fn drop(&mut self) {
         if !self.is_empty() {
             unsafe {
@@ -204,7 +199,7 @@ pub struct Insn<'a> {
 pub struct InsnDetail<'a>(pub(crate) &'a cs_detail, pub(crate) Arch);
 
 #[allow(clippy::len_without_is_empty)]
-impl<'a> Insn<'a> {
+impl Insn<'_> {
     /// Create an `Insn` from a raw pointer to a [`capstone_sys::cs_insn`].
     ///
     /// This function serves to allow integration with libraries which generate `capstone_sys::cs_insn`'s internally.
@@ -225,16 +220,26 @@ impl<'a> Insn<'a> {
         }
     }
 
-    /// The mnemonic for the instruction
+    /// The mnemonic for the instruction.
+    /// Unavailable in Diet mode.
     #[inline]
     pub fn mnemonic(&self) -> Option<&str> {
-        unsafe { str_from_cstr_ptr(self.insn.mnemonic.as_ptr()) }
+        if cfg!(feature = "full") {
+            unsafe { str_from_cstr_ptr(self.insn.mnemonic.as_ptr()) }
+        } else {
+            None
+        }
     }
 
-    /// The operand string associated with the instruction
+    /// The operand string associated with the instruction.
+    /// Unavailable in Diet mode.
     #[inline]
     pub fn op_str(&self) -> Option<&str> {
-        unsafe { str_from_cstr_ptr(self.insn.op_str.as_ptr()) }
+        if cfg!(feature = "full") {
+            unsafe { str_from_cstr_ptr(self.insn.op_str.as_ptr()) }
+        } else {
+            None
+        }
     }
 
     /// Access instruction id
@@ -252,7 +257,7 @@ impl<'a> Insn<'a> {
     /// Instruction address
     #[inline]
     pub fn address(&self) -> u64 {
-        self.insn.address as u64
+        self.insn.address
     }
 
     /// Byte-level representation of the instruction
@@ -275,7 +280,7 @@ impl<'a> Insn<'a> {
     }
 }
 
-impl<'a> From<&Insn<'_>> for OwnedInsn<'a> {
+impl From<&Insn<'_>> for OwnedInsn<'_> {
     // SAFETY: assumes that `cs_detail` struct transitively only contains owned
     // types and no pointers, including the union over the architecture-specific
     // types.
@@ -319,7 +324,7 @@ pub struct OwnedInsn<'a> {
     pub(crate) _marker: PhantomData<&'a InsnDetail<'a>>,
 }
 
-impl<'a> Debug for Insn<'a> {
+impl Debug for Insn<'_> {
     fn fmt(&self, fmt: &mut Formatter) -> Result<(), Error> {
         fmt.debug_struct("Insn")
             .field("address", &self.address())
@@ -330,7 +335,8 @@ impl<'a> Debug for Insn<'a> {
             .finish()
     }
 }
-impl<'a> Display for Insn<'a> {
+
+impl Display for Insn<'_> {
     fn fmt(&self, fmt: &mut Formatter) -> fmt::Result {
         write!(fmt, "{:#x}: ", self.address())?;
         if let Some(mnemonic) = self.mnemonic() {
@@ -343,7 +349,7 @@ impl<'a> Display for Insn<'a> {
     }
 }
 
-impl<'a> Drop for OwnedInsn<'a> {
+impl Drop for OwnedInsn<'_> {
     fn drop(&mut self) {
         if let Some(ptr) = core::ptr::NonNull::new(self.insn.detail) {
             unsafe { drop(Box::from_raw(ptr.as_ptr())) }
@@ -351,22 +357,20 @@ impl<'a> Drop for OwnedInsn<'a> {
     }
 }
 
-impl<'a> Debug for OwnedInsn<'a> {
+impl Debug for OwnedInsn<'_> {
     fn fmt(&self, fmt: &mut Formatter) -> Result<(), Error> {
         Debug::fmt(&self.deref(), fmt)
     }
 }
-impl<'a> Display for OwnedInsn<'a> {
+
+impl Display for OwnedInsn<'_> {
     fn fmt(&self, fmt: &mut Formatter) -> fmt::Result {
         Display::fmt(&self.deref(), fmt)
     }
 }
 
-/// Iterator over instruction group ids
-#[derive(Debug, Clone)]
-pub struct InsnGroupIter<'a>(slice::Iter<'a, InsnGroupIdInt>);
-
-impl<'a> InsnDetail<'a> {
+impl InsnDetail<'_> {
+    #[cfg(feature = "full")]
     /// Returns the implicit read registers
     pub fn regs_read(&self) -> &[RegId] {
         unsafe {
@@ -375,6 +379,7 @@ impl<'a> InsnDetail<'a> {
         }
     }
 
+    #[cfg(feature = "full")]
     /// Returns the implicit write registers
     pub fn regs_write(&self) -> &[RegId] {
         unsafe {
@@ -383,6 +388,7 @@ impl<'a> InsnDetail<'a> {
         }
     }
 
+    #[cfg(feature = "full")]
     /// Returns the groups to which this instruction belongs
     pub fn groups(&self) -> &[InsnGroupId] {
         unsafe {
@@ -407,7 +413,6 @@ impl<'a> InsnDetail<'a> {
                             $detail($insn_detail(unsafe { &self.0.__bindgen_anon_1.$arch }))
                         }
                     )*
-                    _ => panic!("Unsupported detail arch"),
                 }
             }
         }
@@ -424,11 +429,14 @@ impl<'a> InsnDetail<'a> {
             [TMS320C64X, Tms320c64xDetail, Tms320c64xInsnDetail, tms320c64x]
             [X86, X86Detail, X86InsnDetail, x86]
             [XCORE, XcoreDetail, XcoreInsnDetail, xcore]
+            [BPF, BpfDetail, BpfInsnDetail, bpf]
+            [SYSZ, SysZDetail, SysZInsnDetail, sysz]
         );
     }
 }
 
-impl<'a> Debug for InsnDetail<'a> {
+#[cfg(feature = "full")]
+impl Debug for InsnDetail<'_> {
     fn fmt(&self, fmt: &mut Formatter) -> fmt::Result {
         fmt.debug_struct("Detail")
             .field("regs_read", &self.regs_read())
@@ -438,7 +446,14 @@ impl<'a> Debug for InsnDetail<'a> {
     }
 }
 
-impl<'a> Display for Instructions<'a> {
+#[cfg(not(feature = "full"))]
+impl<'a> Debug for InsnDetail<'a> {
+    fn fmt(&self, fmt: &mut Formatter) -> fmt::Result {
+        fmt.debug_struct("Detail").finish()
+    }
+}
+
+impl Display for Instructions<'_> {
     fn fmt(&self, fmt: &mut Formatter) -> fmt::Result {
         for instruction in self.iter() {
             write!(fmt, "{:x}:\t", instruction.address())?;
